@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ ContactEditorWidget::ContactEditorWidget(QWidget *parent)
     createCompleterList();
 }
 
-ContactEditorWidget::~ContactEditorWidget()
-{
-}
+ContactEditorWidget::~ContactEditorWidget() = default;
 
 void ContactEditorWidget::createCompleterList(const QStringList &extraCompletion)
 {
